"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteAccount = void 0;
const commons_1 = require("@wireapp/commons");
const electron_1 = require("electron");
const fs = require("fs-extra");
const path = require("path");
const getLogger_1 = require("../logging/getLogger");
const USER_DATA_DIR = electron_1.app.getPath('userData');
const LOG_DIR = path.join(USER_DATA_DIR, 'logs');
const logger = getLogger_1.getLogger(path.basename(__filename));
const clearStorage = (session) => __awaiter(void 0, void 0, void 0, function* () {
    yield session.clearStorageData();
    yield session.clearCache();
    session.flushStorageData();
});
function deleteAccount(id, accountId, partitionId) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const webviewWebContent = electron_1.webContents.fromId(id);
            if (!webviewWebContent) {
                throw new Error(`Unable to find webview content id "${id}"`);
            }
            if (!webviewWebContent.hostWebContents) {
                throw new Error('Only a webview can have its storage wiped');
            }
            logger.log(`Deleting session data for account "${accountId}"...`);
            yield clearStorage(webviewWebContent.session);
            logger.log(`Deleted session data for account "${accountId}".`);
        }
        catch (error) {
            logger.error(`Failed to delete session data for account "${accountId}", reason: "${error.message}".`);
        }
        if (partitionId) {
            try {
                if (!commons_1.ValidationUtil.isUUIDv4(partitionId)) {
                    throw new Error('Partition is not an UUID');
                }
                const partitionDir = path.join(USER_DATA_DIR, 'Partitions', partitionId);
                yield fs.remove(partitionDir);
                logger.log(`Deleted partition "${partitionId}" for account "${accountId}".`);
            }
            catch (error) {
                logger.log(`Unable to delete partition "${partitionId}" for account "${accountId}", reason: "${error.message}".`);
            }
        }
        try {
            if (!commons_1.ValidationUtil.isUUIDv4(accountId)) {
                throw new Error('Account is not an UUID');
            }
            const sessionFolder = path.join(LOG_DIR, accountId);
            yield fs.remove(sessionFolder);
            logger.log(`Deleted logs folder for account "${accountId}".`);
        }
        catch (error) {
            logger.error(`Failed to delete logs folder for account "${accountId}", reason: "${error.message}".`);
        }
    });
}
exports.deleteAccount = deleteAccount;
//# sourceMappingURL=LocalAccountDeletion.js.map