"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.suggestFileName = exports.downloadFile = exports.downloadImage = exports.downloadLogs = void 0;
const commons_1 = require("@wireapp/commons");
const electron_1 = require("electron");
const image_type_1 = require("image-type");
const fs = require("fs-extra");
const path = require("path");
const getLogger_1 = require("../logging/getLogger");
const logger = getLogger_1.getLogger(path.basename(__filename));
exports.downloadLogs = (bytes, timestamp = new Date()) => __awaiter(void 0, void 0, void 0, function* () {
    const options = {
        filters: [{ extensions: ['zip'], name: 'Archives (*.zip)' }],
    };
    const { date: formattedDate, time: formattedTime } = commons_1.DateUtil.isoFormat(timestamp);
    const formattedTimeShort = formattedTime.replace(/:/g, '-').substr(0, 5);
    const filename = `wire-logs-${formattedDate}-${formattedTimeShort}.zip`;
    return exports.downloadFile(bytes, filename, options);
});
exports.downloadImage = (bytes, timestamp) => __awaiter(void 0, void 0, void 0, function* () {
    const type = image_type_1.default(bytes);
    const options = {};
    let filename = exports.suggestFileName(timestamp);
    if (type === null || type === void 0 ? void 0 : type.ext) {
        options.filters = [
            {
                extensions: [type.ext],
                name: 'Images',
            },
        ];
        filename += `.${type.ext}`;
    }
    return exports.downloadFile(bytes, filename, options);
});
exports.downloadFile = (bytes, filename, options) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { filePath: chosenPath } = yield electron_1.dialog.showSaveDialog(Object.assign({ defaultPath: filename }, options));
        if (chosenPath) {
            yield fs.writeFile(chosenPath, bytes);
        }
    }
    catch (error) {
        logger.error(error);
    }
});
exports.suggestFileName = (timestamp) => {
    const imageDate = timestamp ? new Date(Number(timestamp)) : new Date();
    const { date: formattedDate, time: formattedTime } = commons_1.DateUtil.isoFormat(imageDate);
    return `Wire ${formattedDate} at ${formattedTime}`.replace(/:/g, '-');
};
//# sourceMappingURL=download.js.map