"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const commons_1 = require("@wireapp/commons");
const electron_1 = require("electron");
const fs = require("fs-extra");
const get_proxy_settings_1 = require("get-proxy-settings");
const minimist = require("minimist");
const path = require("path");
const url_1 = require("url");
const windowStateKeeper = require("electron-window-state");
const fileUrl = require("file-url");
require("./global");
const CertificateVerifyProcManager_1 = require("./lib/CertificateVerifyProcManager");
const CoreProtocol_1 = require("./lib/CoreProtocol");
const download_1 = require("./lib/download");
const eventType_1 = require("./lib/eventType");
const LocalAccountDeletion_1 = require("./lib/LocalAccountDeletion");
const locale = require("./locale/locale");
const getLogger_1 = require("./logging/getLogger");
const initRaygun_1 = require("./logging/initRaygun");
const loggerUtils_1 = require("./logging/loggerUtils");
const developer_1 = require("./menu/developer");
const systemMenu = require("./menu/system");
const TrayHandler_1 = require("./menu/TrayHandler");
const EnvironmentUtil = require("./runtime/EnvironmentUtil");
const lifecycle = require("./runtime/lifecycle");
const OriginValidator_1 = require("./runtime/OriginValidator");
const config_1 = require("./settings/config");
const ConfigurationPersistence_1 = require("./settings/ConfigurationPersistence");
const SettingsType_1 = require("./settings/SettingsType");
const SingleSignOn_1 = require("./sso/SingleSignOn");
const AboutWindow_1 = require("./window/AboutWindow");
const ProxyPromptWindow_1 = require("./window/ProxyPromptWindow");
const WindowManager_1 = require("./window/WindowManager");
const WindowUtil = require("./window/WindowUtil");
const ProxyAuth = require("./auth/ProxyAuth");
const showDialog_1 = require("./lib/showDialog");
const APP_PATH = path.join(electron_1.app.getAppPath(), config_1.config.electronDirectory);
const INDEX_HTML = path.join(APP_PATH, 'renderer/index.html');
const LOG_DIR = path.join(electron_1.app.getPath('userData'), 'logs');
const LOG_FILE = path.join(LOG_DIR, 'electron.log');
const PRELOAD_JS = path.join(APP_PATH, 'dist/renderer/preload-app.js');
const PRELOAD_RENDERER_JS = path.join(APP_PATH, 'dist/renderer/preload-webview.js');
const WRAPPER_CSS = path.join(APP_PATH, 'css/wrapper.css');
const WINDOW_SIZE = {
    DEFAULT_HEIGHT: 768,
    DEFAULT_WIDTH: 1024,
    MIN_HEIGHT: 512,
    MIN_WIDTH: 760,
};
let proxyInfoArg;
const customProtocolHandler = new CoreProtocol_1.CustomProtocolHandler();
const argv = minimist(process.argv.slice(1));
const BASE_URL = EnvironmentUtil.web.getWebappUrl(argv[config_1.config.ARGUMENT.ENV]);
const logger = getLogger_1.getLogger(path.basename(__filename));
const currentLocale = locale.getCurrent();
const startHidden = Boolean(argv[config_1.config.ARGUMENT.STARTUP] || argv[config_1.config.ARGUMENT.HIDDEN]);
if (argv[config_1.config.ARGUMENT.VERSION]) {
    console.info(config_1.config.version);
    electron_1.app.exit();
}
logger.info(`Initializing ${config_1.config.name} v${config_1.config.version} ...`);
if (argv[config_1.config.ARGUMENT.PROXY_SERVER]) {
    try {
        proxyInfoArg = new url_1.URL(argv[config_1.config.ARGUMENT.PROXY_SERVER]);
        if (!/^(https?|socks[45]):$/.test(proxyInfoArg.protocol)) {
            throw new Error('Invalid protocol for the proxy server specified.');
        }
        if (proxyInfoArg.origin === 'null') {
            proxyInfoArg = undefined;
            throw new Error('No protocol for the proxy server specified.');
        }
    }
    catch (error) {
        logger.error(`Could not parse authenticated proxy URL: "${error.message}"`);
    }
}
const iconFileName = `logo.${EnvironmentUtil.platform.IS_WINDOWS ? 'ico' : 'png'}`;
const iconPath = path.join(APP_PATH, 'img', iconFileName);
let tray;
let isFullScreen = false;
let isQuitting = false;
let main;
Object.entries(config_1.config).forEach(([key, value]) => {
    if (typeof value === 'undefined' || (typeof value === 'number' && isNaN(value))) {
        logger.warn(`Configuration key "${key}" not defined.`);
    }
});
electron_1.app.setAppUserModelId(`com.squirrel.wire.${config_1.config.name.toLowerCase()}`);
const bindIpcEvents = () => {
    electron_1.ipcMain.on(eventType_1.EVENT_TYPE.ACTION.SAVE_PICTURE, (_event, bytes, timestamp) => {
        return download_1.downloadImage(bytes, timestamp);
    });
    electron_1.ipcMain.on(eventType_1.EVENT_TYPE.ACTION.NOTIFICATION_CLICK, () => {
        WindowManager_1.WindowManager.showPrimaryWindow();
    });
    electron_1.ipcMain.on(eventType_1.EVENT_TYPE.UI.BADGE_COUNT, (_event, count) => {
        tray.showUnreadCount(main, count);
    });
    electron_1.ipcMain.on(eventType_1.EVENT_TYPE.ACCOUNT.DELETE_DATA, (_event, id, accountId, partitionId) => __awaiter(void 0, void 0, void 0, function* () {
        yield LocalAccountDeletion_1.deleteAccount(id, accountId, partitionId);
        main.webContents.send(eventType_1.EVENT_TYPE.ACCOUNT.DATA_DELETED);
    }));
    electron_1.ipcMain.on(eventType_1.EVENT_TYPE.WRAPPER.RELAUNCH, lifecycle.relaunch);
    electron_1.ipcMain.on(eventType_1.EVENT_TYPE.ABOUT.SHOW, AboutWindow_1.AboutWindow.showWindow);
};
const checkConfigV0FullScreen = (mainWindowState) => {
    if (typeof mainWindowState.isMaximized === 'undefined' && isFullScreen === true) {
        main.maximize();
    }
};
const initWindowStateKeeper = () => {
    const loadedWindowBounds = ConfigurationPersistence_1.settings.restore(SettingsType_1.SettingsType.WINDOW_BOUNDS, {
        height: WINDOW_SIZE.DEFAULT_HEIGHT,
        width: WINDOW_SIZE.DEFAULT_WIDTH,
    });
    const showInFullScreen = ConfigurationPersistence_1.settings.restore(SettingsType_1.SettingsType.FULL_SCREEN, 'not-set-in-v0');
    const stateKeeperOptions = {
        defaultHeight: loadedWindowBounds.height,
        defaultWidth: loadedWindowBounds.width,
        path: path.join(electron_1.app.getPath('userData'), 'config'),
    };
    if (showInFullScreen !== 'not-set-in-v0') {
        stateKeeperOptions.fullScreen = showInFullScreen;
        stateKeeperOptions.maximize = showInFullScreen;
        isFullScreen = showInFullScreen;
    }
    return windowStateKeeper(stateKeeperOptions);
};
const showMainWindow = (mainWindowState) => __awaiter(void 0, void 0, void 0, function* () {
    const showMenuBar = ConfigurationPersistence_1.settings.restore(SettingsType_1.SettingsType.SHOW_MENU_BAR, true);
    const options = {
        autoHideMenuBar: !showMenuBar,
        backgroundColor: '#f7f8fa',
        height: mainWindowState.height,
        icon: iconPath,
        minHeight: WINDOW_SIZE.MIN_HEIGHT,
        minWidth: WINDOW_SIZE.MIN_WIDTH,
        show: false,
        title: config_1.config.name,
        titleBarStyle: 'hiddenInset',
        webPreferences: {
            backgroundThrottling: false,
            enableBlinkFeatures: '',
            nodeIntegration: false,
            preload: PRELOAD_JS,
            webviewTag: true,
        },
        width: mainWindowState.width,
        x: mainWindowState.x,
        y: mainWindowState.y,
    };
    main = new electron_1.BrowserWindow(options);
    main.setMenuBarVisibility(showMenuBar);
    mainWindowState.manage(main);
    CertificateVerifyProcManager_1.attachTo(main);
    checkConfigV0FullScreen(mainWindowState);
    const webappURL = new url_1.URL(BASE_URL);
    webappURL.searchParams.set('hl', currentLocale);
    if (getLogger_1.ENABLE_LOGGING) {
        webappURL.searchParams.set('enableLogging', '@wireapp/*');
    }
    if (customProtocolHandler.hashLocation) {
        webappURL.hash = customProtocolHandler.hashLocation;
    }
    if (argv.devtools) {
        main.webContents.openDevTools({ mode: 'detach' });
    }
    if (!startHidden) {
        if (!WindowUtil.isInView(main)) {
            main.center();
        }
        WindowManager_1.WindowManager.setPrimaryWindowId(main.id);
        setTimeout(() => main.show(), 800);
    }
    main.webContents.on('will-navigate', event => {
        event.preventDefault();
    });
    main.webContents.on('new-window', (event, url) => __awaiter(void 0, void 0, void 0, function* () {
        event.preventDefault();
        if (typeof event.sender.viewInstanceId !== 'undefined') {
            logger.log('New window was created from a webview, aborting.');
            return;
        }
        yield electron_1.shell.openExternal(url);
    }));
    main.on('focus', () => {
        systemMenu.registerGlobalShortcuts();
        main.flashFrame(false);
    });
    main.on('blur', () => systemMenu.unregisterGlobalShortcuts());
    main.on('page-title-updated', () => tray.showUnreadCount(main));
    main.on('close', event => {
        if (!isQuitting) {
            event.preventDefault();
            logger.log('Closing window...');
            if (main.isFullScreen()) {
                logger.log('Fullscreen detected, leaving full screen before hiding...');
                main.once('leave-full-screen', () => main.hide());
                main.setFullScreen(false);
            }
            else {
                main.hide();
            }
            systemMenu.unregisterGlobalShortcuts();
        }
    });
    main.webContents.on('crashed', event => {
        logger.error('WebContents crashed. Will reload the window.');
        logger.error(event);
        try {
            main.reload();
        }
        catch (error) {
            showDialog_1.showErrorDialog(`Could not reload the window: ${error.message}`);
            logger.error('Could not reload the window:', error);
        }
    });
    electron_1.app.on('gpu-process-crashed', event => {
        logger.error('GPU process crashed. Will reload the window.');
        logger.error(event);
        try {
            main.reload();
        }
        catch (error) {
            showDialog_1.showErrorDialog(`Could not reload the window: ${error.message}`);
            logger.error('Could not reload the window:', error);
        }
    });
    const mainURL = new url_1.URL(fileUrl(INDEX_HTML));
    mainURL.searchParams.set('env', encodeURIComponent(webappURL.href));
    mainURL.searchParams.set('focus', String(!startHidden));
    yield main.loadURL(mainURL.href);
    const wrapperCSSContent = yield fs.readFile(WRAPPER_CSS, 'utf8');
    yield main.webContents.insertCSS(wrapperCSSContent);
});
const handleAppEvents = () => {
    electron_1.app.on('window-all-closed', () => __awaiter(void 0, void 0, void 0, function* () {
        if (!EnvironmentUtil.platform.IS_MAC_OS) {
            yield lifecycle.quit();
        }
    }));
    electron_1.app.on('activate', () => {
        if (main) {
            main.show();
        }
    });
    electron_1.app.on('before-quit', () => {
        isQuitting = true;
    });
    electron_1.app.on('login', (event, webContents, _responseDetails, authInfo, callback) => __awaiter(void 0, void 0, void 0, function* () {
        if (authInfo.isProxy) {
            event.preventDefault();
            const { host, port } = authInfo;
            const systemProxy = yield get_proxy_settings_1.getProxySettings();
            const systemProxySettings = systemProxy && (systemProxy.http || systemProxy.https);
            if (systemProxySettings) {
                const { credentials: { username, password }, protocol, } = systemProxySettings;
                proxyInfoArg = ProxyAuth.generateProxyURL({ host, port }, { password, protocol, username });
                logger.log('Found system proxy settings, applying settings on the main window...');
                yield applyProxySettings(proxyInfoArg, main.webContents);
                return callback(username, password);
            }
            if (proxyInfoArg) {
                electron_1.ipcMain.once(eventType_1.EVENT_TYPE.PROXY_PROMPT.SUBMITTED, (_event, promptData) => __awaiter(void 0, void 0, void 0, function* () {
                    var _a;
                    logger.log('Proxy info was submitted via prompt');
                    const { username, password } = promptData;
                    const protocol = (_a = proxyInfoArg === null || proxyInfoArg === void 0 ? void 0 : proxyInfoArg.protocol) === null || _a === void 0 ? void 0 : _a.replace(':', '');
                    proxyInfoArg = ProxyAuth.generateProxyURL({ host, port }, Object.assign(Object.assign({}, promptData), { protocol }));
                    logger.log('Proxy prompt was submitted, applying proxy settings on the main window...');
                    yield applyProxySettings(proxyInfoArg, main.webContents);
                    callback(username, password);
                }));
                electron_1.ipcMain.once(eventType_1.EVENT_TYPE.PROXY_PROMPT.CANCELED, () => __awaiter(void 0, void 0, void 0, function* () {
                    logger.log('Proxy prompt was canceled');
                    yield webContents.session.setProxy({});
                    try {
                        main.reload();
                    }
                    catch (error) {
                        showDialog_1.showErrorDialog(`Could not reload the window: ${error.message}`);
                        logger.error('Could not reload the window:', error);
                    }
                }));
                yield ProxyPromptWindow_1.ProxyPromptWindow.showWindow();
            }
        }
    }));
    electron_1.app.on('ready', () => __awaiter(void 0, void 0, void 0, function* () {
        const mainWindowState = initWindowStateKeeper();
        const appMenu = systemMenu.createMenu(isFullScreen);
        if (EnvironmentUtil.app.IS_DEVELOPMENT) {
            appMenu.append(developer_1.developerMenu);
        }
        electron_1.Menu.setApplicationMenu(appMenu);
        tray = new TrayHandler_1.TrayHandler();
        if (!EnvironmentUtil.platform.IS_MAC_OS) {
            tray.initTray();
        }
        yield showMainWindow(mainWindowState);
    }));
};
const renameFileExtensions = (files, oldExtension, newExtension) => {
    for (const file of files) {
        try {
            const fileStat = fs.statSync(file);
            if (fileStat.isFile() && file.endsWith(oldExtension)) {
                fs.renameSync(file, file.replace(oldExtension, newExtension));
            }
        }
        catch (error) {
            logger.error(`Failed to rename log file: "${error.message}"`);
        }
    }
};
const renameWebViewLogFiles = () => {
    try {
        const logFiles = loggerUtils_1.getLogFilenames(LOG_DIR, true);
        renameFileExtensions(logFiles, '.log', '.old');
    }
    catch (error) {
        logger.log(`Failed to read log directory with error: ${error.message}`);
    }
};
const addLinuxWorkarounds = () => {
    if (EnvironmentUtil.platform.IS_LINUX) {
        if (EnvironmentUtil.linuxDesktop.isUbuntuUnity ||
            EnvironmentUtil.linuxDesktop.isPopOS ||
            EnvironmentUtil.linuxDesktop.isGnomeX11) {
            process.env.XDG_CURRENT_DESKTOP = 'Unity';
        }
    }
};
const handlePortableFlags = () => {
    if (argv[config_1.config.ARGUMENT.USER_DATA_DIR] || argv[config_1.config.ARGUMENT.PORTABLE]) {
        const USER_PATH = argv[config_1.config.ARGUMENT.USER_DATA_DIR]
            ? path.resolve(argv[config_1.config.ARGUMENT.USER_DATA_DIR])
            : path.join(process.env.APPIMAGE || process.execPath, '../Data');
        logger.log(`Saving user data to "${USER_PATH}".`);
        electron_1.app.setPath('userData', USER_PATH);
    }
};
const applyProxySettings = (authenticatedProxyDetails, webContents) => __awaiter(void 0, void 0, void 0, function* () {
    const proxyURL = authenticatedProxyDetails.origin.split('://')[1];
    const proxyProtocol = authenticatedProxyDetails.protocol;
    const isSocksProxy = proxyProtocol === 'socks4:' || proxyProtocol === 'socks5:';
    logger.info(`Setting proxy on the window to URL "${proxyURL}" with protocol "${proxyProtocol}"...`);
    webContents.session.allowNTLMCredentialsForDomains(authenticatedProxyDetails.hostname);
    const proxyRules = isSocksProxy ? `socks=${proxyURL}` : `http=${proxyURL};https=${proxyURL}`;
    yield webContents.session.setProxy({ pacScript: '', proxyBypassRules: '', proxyRules });
});
class ElectronWrapperInit {
    constructor() {
        this.logger = getLogger_1.getLogger('ElectronWrapperInit');
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.log('webviewProtection init');
            this.webviewProtection();
        });
    }
    webviewProtection() {
        const openLinkInNewWindow = (event, url, frameName, _disposition, options) => {
            event.preventDefault();
            if (SingleSignOn_1.SingleSignOn.isSingleSignOnLoginWindow(frameName)) {
                return new SingleSignOn_1.SingleSignOn(main, event, url, options).init();
            }
            this.logger.log('Opening an external window from a webview.');
            return electron_1.shell.openExternal(url);
        };
        const willNavigateInWebview = (event, url, baseUrl) => {
            if (OriginValidator_1.OriginValidator.isMatchingHost(url, baseUrl)) {
                this.logger.log(`Navigating inside webview. URL: ${url}`);
            }
            else {
                this.logger.log(`Preventing navigation inside <webview>. URL: ${url}`);
                event.preventDefault();
            }
        };
        const enableSpellChecking = ConfigurationPersistence_1.settings.restore(SettingsType_1.SettingsType.ENABLE_SPELL_CHECKING, true);
        electron_1.app.on('web-contents-created', (_webviewEvent, contents) => __awaiter(this, void 0, void 0, function* () {
            switch (contents.getType()) {
                case 'window': {
                    contents.on('will-attach-webview', (_event, webPreferences, params) => {
                        params.autosize = 'false';
                        params.contextIsolation = 'true';
                        params.plugins = 'false';
                        webPreferences.allowRunningInsecureContent = false;
                        webPreferences.enableBlinkFeatures = '';
                        webPreferences.experimentalFeatures = true;
                        webPreferences.nodeIntegration = false;
                        webPreferences.preload = PRELOAD_RENDERER_JS;
                        webPreferences.spellcheck = enableSpellChecking;
                        webPreferences.webSecurity = true;
                    });
                    break;
                }
                case 'webview': {
                    if ((proxyInfoArg === null || proxyInfoArg === void 0 ? void 0 : proxyInfoArg.origin) && contents.session) {
                        this.logger.log('Found proxy settings in arguments, applying settings on the webview...');
                        yield applyProxySettings(proxyInfoArg, contents);
                    }
                    contents.on('new-window', openLinkInNewWindow);
                    contents.on('will-navigate', (event, url) => {
                        willNavigateInWebview(event, url, contents.getURL());
                    });
                    if (getLogger_1.ENABLE_LOGGING) {
                        const colorCodeRegex = /%c(.+?)%c/gm;
                        const accessTokenRegex = /access_token=[^ &]+/gm;
                        contents.on('console-message', (_event, _level, message) => __awaiter(this, void 0, void 0, function* () {
                            const webViewId = lifecycle.getWebViewId(contents);
                            if (webViewId) {
                                try {
                                    yield commons_1.LogFactory.writeMessage(message.replace(colorCodeRegex, '$1').replace(accessTokenRegex, ''), LOG_FILE);
                                }
                                catch (error) {
                                    logger.error(`Cannot write to log file "${LOG_FILE}": ${error.message}`, error);
                                }
                            }
                        }));
                    }
                    if (enableSpellChecking) {
                        try {
                            const availableSpellCheckerLanguages = contents.session.availableSpellCheckerLanguages;
                            const foundLanguages = locale.supportedSpellCheckLanguages[currentLocale].filter(language => availableSpellCheckerLanguages.includes(language));
                            contents.session.setSpellCheckerLanguages(foundLanguages);
                        }
                        catch (error) {
                            logger.error(error);
                            contents.session.setSpellCheckerLanguages([]);
                        }
                    }
                    contents.session.setCertificateVerifyProc(CertificateVerifyProcManager_1.setCertificateVerifyProc);
                    const isLocalhostEnvironment = EnvironmentUtil.getEnvironment() == EnvironmentUtil.BackendType.LOCALHOST.toUpperCase();
                    if (isLocalhostEnvironment) {
                        const filter = {
                            urls: config_1.config.backendOrigins.map(value => `${value}/*`),
                        };
                        const listenerOnHeadersReceived = (details, callback) => {
                            const responseHeaders = {
                                'Access-Control-Allow-Credentials': ['true'],
                                'Access-Control-Allow-Origin': [EnvironmentUtil.URL_WEBAPP.LOCALHOST],
                            };
                            callback({
                                cancel: false,
                                responseHeaders: Object.assign(Object.assign({}, details.responseHeaders), responseHeaders),
                            });
                        };
                        contents.session.webRequest.onHeadersReceived(filter, listenerOnHeadersReceived);
                    }
                    contents.on('before-input-event', (_event, input) => {
                        if (input.type === 'keyUp' && input.key === 'Alt') {
                            const mainBrowserWindow = WindowManager_1.WindowManager.getPrimaryWindow();
                            if (mainBrowserWindow) {
                                const isAutoHide = mainBrowserWindow.isMenuBarAutoHide();
                                const isVisible = mainBrowserWindow.isMenuBarVisible();
                                if (isAutoHide) {
                                    mainBrowserWindow.setMenuBarVisibility(!isVisible);
                                }
                            }
                        }
                    });
                    break;
                }
            }
        }));
    }
}
customProtocolHandler.registerCoreProtocol();
initRaygun_1.Raygun.initClient();
handlePortableFlags();
lifecycle
    .checkSingleInstance()
    .then(() => lifecycle.initSquirrelListener())
    .catch(error => logger.error(error));
if (lifecycle.isFirstInstance) {
    addLinuxWorkarounds();
    bindIpcEvents();
    handleAppEvents();
    renameWebViewLogFiles();
    fs.ensureFileSync(LOG_FILE);
    new ElectronWrapperInit().run().catch(error => logger.error(error));
}
//# sourceMappingURL=main.js.map