"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.developerMenu = void 0;
const electron_1 = require("electron");
const EnvironmentUtil = require("../runtime/EnvironmentUtil");
const lifecycle = require("../runtime/lifecycle");
const config_1 = require("../settings/config");
const WindowManager_1 = require("../window/WindowManager");
const currentEnvironment = EnvironmentUtil.getEnvironment();
const reloadTemplate = {
    click: () => {
        const primaryWindow = WindowManager_1.WindowManager.getPrimaryWindow();
        if (primaryWindow) {
            primaryWindow.reload();
        }
    },
    label: 'Reload',
};
const devToolsTemplate = {
    label: 'Toggle DevTools',
    submenu: [
        {
            accelerator: 'Alt+CmdOrCtrl+I',
            click: () => {
                const primaryWindow = WindowManager_1.WindowManager.getPrimaryWindow();
                if (primaryWindow) {
                    primaryWindow.webContents.toggleDevTools();
                }
            },
            label: 'Sidebar',
        },
        {
            click: () => __awaiter(void 0, void 0, void 0, function* () {
                const primaryWindow = WindowManager_1.WindowManager.getPrimaryWindow();
                if (primaryWindow) {
                    const command = 'document.getElementsByTagName("webview")[0].openDevTools({mode: "detach"})';
                    yield primaryWindow.webContents.executeJavaScript(command);
                }
            }),
            label: 'First',
        },
        {
            click: () => __awaiter(void 0, void 0, void 0, function* () {
                const primaryWindow = WindowManager_1.WindowManager.getPrimaryWindow();
                if (primaryWindow) {
                    const command = 'document.getElementsByTagName("webview")[1].openDevTools({mode: "detach"})';
                    yield primaryWindow.webContents.executeJavaScript(command);
                }
            }),
            label: 'Second',
        },
        {
            click: () => __awaiter(void 0, void 0, void 0, function* () {
                const primaryWindow = WindowManager_1.WindowManager.getPrimaryWindow();
                if (primaryWindow) {
                    const command = 'document.getElementsByTagName("webview")[2].openDevTools({mode: "detach"})';
                    yield primaryWindow.webContents.executeJavaScript(command);
                }
            }),
            label: 'Third',
        },
    ],
};
const createEnvironmentTemplates = () => {
    const environmentTemplate = [];
    const environments = Object.assign({}, EnvironmentUtil.URL_WEBAPP);
    delete environments.CUSTOM;
    for (const [backendType, backendURL] of Object.entries(environments)) {
        environmentTemplate.push({
            checked: currentEnvironment === backendType,
            click: () => __awaiter(void 0, void 0, void 0, function* () {
                EnvironmentUtil.setEnvironment(backendType);
                yield lifecycle.relaunch();
            }),
            label: backendURL.replace(/^https?:\/\//, ''),
            type: 'radio',
        });
    }
    return environmentTemplate;
};
const versionTemplate = {
    enabled: false,
    label: `${config_1.config.name} Version ${config_1.config.version || 'Development'}`,
};
const chromeVersionTemplate = {
    enabled: false,
    label: `Chrome Version ${process.versions.chrome}`,
};
const electronVersionTemplate = {
    enabled: false,
    label: `Electron Version ${process.versions.electron}`,
};
const separatorTemplate = {
    type: 'separator',
};
const menuTemplate = {
    id: 'Developer',
    label: '&Developer',
    submenu: [
        devToolsTemplate,
        reloadTemplate,
        separatorTemplate,
        {
            enabled: false,
            label: 'Environment',
        },
        ...createEnvironmentTemplates(),
        separatorTemplate,
        versionTemplate,
        chromeVersionTemplate,
        electronVersionTemplate,
    ],
};
exports.developerMenu = new electron_1.MenuItem(menuTemplate);
//# sourceMappingURL=developer.js.map