"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const eventType_1 = require("../../lib/eventType");
const locale = require("../../locale/locale");
const config_1 = require("../../settings/config");
const Menu = electron_1.remote.Menu;
const savePicture = (url, timestamp) => __awaiter(void 0, void 0, void 0, function* () {
    const response = yield fetch(url, {
        headers: {
            'User-Agent': config_1.config.userAgent,
        },
    });
    const arrayBuffer = yield response.arrayBuffer();
    electron_1.ipcRenderer.send(eventType_1.EVENT_TYPE.ACTION.SAVE_PICTURE, new Uint8Array(arrayBuffer), timestamp);
});
const createDefaultMenu = (copyContext) => Menu.buildFromTemplate([
    {
        click: () => electron_1.clipboard.writeText(copyContext),
        label: locale.getText('menuCopy'),
    },
]);
const createTextMenu = (params, webContents) => {
    const { editFlags, dictionarySuggestions } = params;
    const template = [
        {
            enabled: editFlags.canCut,
            label: locale.getText('menuCut'),
            role: 'cut',
        },
        {
            enabled: editFlags.canCopy,
            label: locale.getText('menuCopy'),
            role: 'copy',
        },
        {
            enabled: editFlags.canPaste,
            label: locale.getText('menuPaste'),
            role: 'paste',
        },
        {
            type: 'separator',
        },
        {
            enabled: editFlags.canSelectAll,
            label: locale.getText('menuSelectAll'),
            role: 'selectAll',
        },
    ];
    if (dictionarySuggestions.length > 0) {
        template.push({
            type: 'separator',
        });
        for (const suggestion of dictionarySuggestions) {
            template.push({
                click: () => webContents.replaceMisspelling(suggestion),
                label: suggestion,
            });
        }
    }
    return Menu.buildFromTemplate(template);
};
const imageMenu = Menu.buildFromTemplate([
    {
        click: () => savePicture(imageMenu.image || '', imageMenu.timestamp),
        label: locale.getText('menuSavePictureAs'),
    },
]);
const webContents = electron_1.remote.getCurrentWebContents();
webContents.on('context-menu', (_event, params) => {
    const window = electron_1.remote.getCurrentWindow();
    if (params.isEditable) {
        const textMenu = createTextMenu(params, webContents);
        textMenu.popup({ window });
    }
    else if (params.mediaType === 'image') {
        imageMenu.image = params.srcURL;
        imageMenu.popup({ window });
    }
    else if (!!params.linkURL) {
        const copyContext = params.linkURL.replace(/^mailto:/, '');
        createDefaultMenu(copyContext).popup({ window });
    }
    else if (!!params.selectionText || params.editFlags.canCopy) {
        const copyContext = params.selectionText;
        createDefaultMenu(copyContext).popup({ window });
    }
    else if (params.editFlags.canSelectAll) {
        let element = document.elementFromPoint(params.x, params.y);
        while (element && element !== document && !element.classList.contains('text')) {
            element = element.parentNode;
        }
        if (element) {
            const copyContext = (params.selectionText || '').toString() || (element.innerText || '').trim();
            if (copyContext) {
                createDefaultMenu(copyContext).popup({ window });
            }
        }
    }
});
//# sourceMappingURL=context.js.map