"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const path = require("path");
const eventType_1 = require("../lib/eventType");
const locale = require("../locale/locale");
const getLogger_1 = require("../logging/getLogger");
const EnvironmentUtil = require("../runtime/EnvironmentUtil");
const AutomatedSingleSignOn_1 = require("../sso/AutomatedSingleSignOn");
const logger = getLogger_1.getLogger(path.basename(__filename));
electron_1.webFrame.setZoomFactor(1.0);
electron_1.webFrame.setVisualZoomLevelLimits(1, 1);
window.locStrings = locale.LANGUAGES[locale.getCurrent()];
window.locStringsDefault = locale.LANGUAGES.en;
window.isMac = EnvironmentUtil.platform.IS_MAC_OS;
const getSelectedWebview = () => document.querySelector('.Webview:not(.hide)');
const getWebviewById = (id) => document.querySelector(`.Webview[data-accountid="${id}"]`);
const subscribeToMainProcessEvents = () => {
    electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.ACCOUNT.SSO_LOGIN, (_event, code) => new AutomatedSingleSignOn_1.AutomatedSingleSignOn().start(code));
    electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.UI.SYSTEM_MENU, (_event, action) => __awaiter(void 0, void 0, void 0, function* () {
        const selectedWebview = getSelectedWebview();
        if (selectedWebview) {
            yield selectedWebview.send(action);
        }
    }));
    electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.WEBAPP.CHANGE_LOCATION_HASH, (_event, hash) => __awaiter(void 0, void 0, void 0, function* () {
        const selectedWebview = getSelectedWebview();
        if (selectedWebview) {
            yield selectedWebview.send(eventType_1.EVENT_TYPE.WEBAPP.CHANGE_LOCATION_HASH, hash);
        }
    }));
    electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.EDIT.REDO, () => {
        const selectedWebview = getSelectedWebview();
        if (selectedWebview) {
            selectedWebview.redo();
        }
    });
    electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.EDIT.UNDO, () => {
        const selectedWebview = getSelectedWebview();
        if (selectedWebview) {
            selectedWebview.undo();
        }
    });
    electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.WRAPPER.RELOAD, () => {
        const webviews = document.querySelectorAll('webview');
        webviews.forEach(webview => webview.reload());
    });
    electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.ACTION.SWITCH_ACCOUNT, (event, accountIndex) => {
        window.dispatchEvent(new CustomEvent(eventType_1.EVENT_TYPE.ACTION.SWITCH_ACCOUNT, { detail: { accountIndex } }));
    });
};
const setupIpcInterface = () => {
    window.sendBadgeCount = (count) => {
        electron_1.ipcRenderer.send(eventType_1.EVENT_TYPE.UI.BADGE_COUNT, count);
    };
    window.sendDeleteAccount = (accountID, sessionID) => {
        return new Promise((resolve, reject) => {
            const accountWebview = getWebviewById(accountID);
            if (!accountWebview) {
                return reject(`Webview for account "${accountID}" does not exist`);
            }
            logger.info(`Processing deletion of "${accountID}"`);
            const viewInstanceId = accountWebview.getWebContentsId();
            electron_1.ipcRenderer.on(eventType_1.EVENT_TYPE.ACCOUNT.DATA_DELETED, () => resolve());
            electron_1.ipcRenderer.send(eventType_1.EVENT_TYPE.ACCOUNT.DELETE_DATA, viewInstanceId, accountID, sessionID);
        });
    };
    window.sendLogoutAccount = (accountId) => __awaiter(void 0, void 0, void 0, function* () {
        const accountWebview = getWebviewById(accountId);
        if (accountWebview) {
            logger.log(`Sending logout signal to webview for account "${accountId}".`);
            yield accountWebview.send(eventType_1.EVENT_TYPE.ACTION.SIGN_OUT);
        }
    });
};
const addDragRegion = () => {
    if (EnvironmentUtil.platform.IS_MAC_OS) {
        const titleBar = document.createElement('div');
        titleBar.className = 'drag-region';
        document.body.appendChild(titleBar);
    }
};
setupIpcInterface();
subscribeToMainProcessEvents();
window.addEventListener('DOMContentLoaded', addDragRegion);
window.addEventListener('focus', () => {
    const selectedWebview = getSelectedWebview();
    if (selectedWebview) {
        selectedWebview.blur();
        selectedWebview.focus();
    }
});
//# sourceMappingURL=preload-app.js.map