"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AboutWindow = void 0;
const electron_1 = require("electron");
const fileUrl = require("file-url");
const path = require("path");
const eventType_1 = require("../lib/eventType");
const locale = require("../locale/locale");
const EnvironmentUtil = require("../runtime/EnvironmentUtil");
const config_1 = require("../settings/config");
const getLogger_1 = require("../logging/getLogger");
const logger = getLogger_1.getLogger(path.basename(__filename));
let webappVersion;
const APP_PATH = path.join(electron_1.app.getAppPath(), config_1.config.electronDirectory);
const iconFileName = `logo.${EnvironmentUtil.platform.IS_WINDOWS ? 'ico' : 'png'}`;
const iconPath = path.join(APP_PATH, 'img', iconFileName);
const ABOUT_HTML = fileUrl(path.join(APP_PATH, 'html/about.html'));
const ABOUT_WINDOW_ALLOWLIST = [
    ABOUT_HTML,
    fileUrl(path.join(APP_PATH, 'img/logo.256.png')),
    fileUrl(path.join(APP_PATH, 'css/about.css')),
];
const PRELOAD_JS = path.join(APP_PATH, 'dist/renderer/menu/preload-about.js');
const WINDOW_SIZE = {
    HEIGHT: 256,
    WIDTH: 304,
};
electron_1.ipcMain.once(eventType_1.EVENT_TYPE.UI.WEBAPP_VERSION, (_event, version) => (webappVersion = version));
const showWindow = () => __awaiter(void 0, void 0, void 0, function* () {
    let aboutWindow;
    if (!aboutWindow) {
        aboutWindow = new electron_1.BrowserWindow({
            alwaysOnTop: true,
            backgroundColor: '#ececec',
            fullscreen: false,
            height: WINDOW_SIZE.HEIGHT,
            icon: iconPath,
            maximizable: false,
            minimizable: false,
            resizable: false,
            show: false,
            title: config_1.config.name,
            webPreferences: {
                enableBlinkFeatures: '',
                javascript: false,
                nodeIntegration: false,
                nodeIntegrationInWorker: false,
                preload: PRELOAD_JS,
                session: electron_1.session.fromPartition('about-window'),
                spellcheck: false,
                webviewTag: false,
            },
            width: WINDOW_SIZE.WIDTH,
        });
        aboutWindow.setMenuBarVisibility(false);
        aboutWindow.webContents.session.webRequest.onBeforeRequest(({ url }, callback) => __awaiter(void 0, void 0, void 0, function* () {
            if (ABOUT_WINDOW_ALLOWLIST.includes(url)) {
                return callback({ cancel: false });
            }
            if (url.startsWith('https://')) {
                yield electron_1.shell.openExternal(url);
            }
            else {
                logger.info(`Attempt to open URL "${url}" in window prevented.`);
                callback({ redirectURL: ABOUT_HTML });
            }
        }));
        electron_1.ipcMain.on(eventType_1.EVENT_TYPE.ABOUT.LOCALE_VALUES, (event, labels) => {
            if (aboutWindow) {
                const isExpected = event.sender.id === aboutWindow.webContents.id;
                if (isExpected) {
                    const resultLabels = {};
                    labels.forEach(label => (resultLabels[label] = locale.getText(label)));
                    event.sender.send(eventType_1.EVENT_TYPE.ABOUT.LOCALE_RENDER, resultLabels);
                }
            }
        });
        aboutWindow.webContents.on('before-input-event', (_event, input) => {
            if (input.type === 'keyDown' && input.key === 'Escape') {
                if (aboutWindow) {
                    aboutWindow.close();
                }
            }
        });
        aboutWindow.on('closed', () => (aboutWindow = undefined));
        yield aboutWindow.loadURL(ABOUT_HTML);
        if (aboutWindow) {
            aboutWindow.webContents.send(eventType_1.EVENT_TYPE.ABOUT.LOADED, {
                copyright: config_1.config.copyright,
                electronVersion: config_1.config.version,
                productName: config_1.config.name,
                webappVersion,
            });
        }
    }
    aboutWindow.show();
});
exports.AboutWindow = { showWindow };
//# sourceMappingURL=AboutWindow.js.map